# lonboard

[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/developmentseed/lonboard/HEAD)

Python library for extremely fast geospatial vector data visualization in Jupyter.

![](assets/scatterplot-layer-network-speeds.jpg)

## Install

```
pip install --pre lonboard
```

## Documentation

Refer to the documentation at [developmentseed.org/lonboard](https://developmentseed.org/lonboard/).

## Why the name?

This is a new binding to the [deck.gl](https://deck.gl) geospatial data visualization library. A "deck" is the part of a skateboard you ride on. What's a fast, geospatial skateboard? A <em>lon</em>board.

<img src="https://upload.wikimedia.org/wikipedia/commons/a/aa/Longboard.JPG" height="300" />

[CC-BY from Wikipedia](https://commons.wikimedia.org/wiki/File:Longboard.JPG)
